==> nextcloud-app-mail-5.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sw.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Muhimu",
    "Work" : "Kazi",
    "Personal" : "Binafsi",
    "To Do" : "Kufanya",
    "Later" : "Baadaye",
    "Mail" : "Msururu wa maduka",
    "Sign in with Google" : "Ingia kwa Google",
    "Save" : "Hifadhi",
    "Connect" : "Unganisha",
    "Auto" : "Auto",
    "Name" : "Jina",
    "Password" : "Nenosiri",
    "None" : "Hakuna",
    "Signature" : "Saini",
    "Filters" : "Filters",
    "Go back" : "Rudi nyuma",
    "Email address" : "Anwani ya barua pepe",
    "Cancel" : "Cancel",
    "Accounts" : "Akaunti",
    "General" : "Kuu",
    "Layout" : "Mpangilio",
    "List" : "Orodha",
    "Register" : "Sajiri",
    "About" : "Kuhusu",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Archive" : "Weka kumbukumbu",
    "Delete" : "Futa",
    "Search" : "Tafuta",
    "Send" : "Tuma",
    "Refresh" : "Refresh",
    "Ok" : "Sawa",
    "From" : "Tangu/ kutoka",
    "Select account" : "Chagua akaunti",
    "To" : "Mpaka/ hadi",
    "Choose" : "Chagua",
    "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
    "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Confirm" : "Thibitisha",
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Set reminder for next week" : "Set reminder for next week",
    "Favorite" : "Kipendwa",
    "Unread" : "Unread",
    "Read" : "Soma",
    "Delete message" : "Delete message",
    "More actions" : "Vitendo zaidi",
    "Back" : "Rudi",
    "Create event" : "Tengeneza matukio",
    "Create task" : "Tengeneza jukumu",
    "Load more" : "Pakia zaidi",
    "All day" : "Siku yote",
    "Description" : "Maelezo",
    "Create" : "Tengeneza",
    "Select" : "Chagua",
    "Comment" : "Maoni",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "More options" : "Mibadala zaidi",
    "Remove" : "Ondoa",
    "Today" : "Leo",
    "Yesterday" : "Jana",
    "Last week" : "Wiki iliyopita",
    "Last month" : "Mwezi uliopita",
    "Choose target folder" : "Chagua kasha lililolengwa",
    "Other" : "Mengine",
    "Forward" : "Mbele",
    "Translate" : "Tafsiri",
    "Move" : "Hamisha",
    "Remove account" : "Ondoa akaunti",
    "Remove {email}" : "Remove {email}",
    "Add folder" : "Ongeza kisanduku",
    "Folder name" : "Jina la kisanduku",
    "Loading …" : "Inapakia",
    "Delete folder" : "Futa kisanduku",
    "Mark all as read" : "Mark all as read",
    "Rename" : "Ipe jina jipya",
    "Clear cache" : "Clear cache",
    "Subscribed" : "Iliyojisajili",
    "Edit message" : "Hariri ujumbe",
    "Draft" : "Draft",
    "Reply" : "Jibu",
    "Retry" : "Jaribu tene",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
    "Add" : "Ongeza",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Clear" : "Futa",
    "Close" : "Funga",
    "Body" : "Body",
    "Date" : "Tarehe",
    "Tags" : "Maoni",
    "Select tags" : "Chagua ukumbusho",
    "Last 7 days" : "Siku 7 zilizopita",
    "Custom" : "Mteja",
    "Add tag" : "Add tag",
    "Not found" : "Haipatikani",
    "Unsubscribe" : "Unsubscribe",
    "Mark as unread" : "Weka alama kama haijasomwa",
    "Mark as read" : "Weka alama kama iliyosomwa",
    "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
    "Untitled event" : "Tukio lisilotajwa",
    "(organizer)" : "(Mratibu)",
    "Operator" : "Operator",
    "contains" : "contains",
    "matches" : "matches",
    "Priority" : "Kipaumbele",
    "Reset" : "Pangilia upya",
    "Client ID" : "Kitambulisho cha mteja",
    "Client secret" : "Siri ya mteja",
    "User" : "Mtumiaji",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Halali mpaka",
    "Certificate" : "Cheti",
    "Submit" : "Wasilisha",
    "Guest" : "Mgeni",
    "Group" : "Kundi",
    "Shared" : "Imeshirikishwa",
    "Shares" : "Shiriki",
    "Account connected" : "Akaunti imeunganishwa",
    "All" : "Zote",
    "Favorites" : "Vipendwa",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "Nextcloud Mail" : "Nextcloud Mail",
    "Discard changes" : "Discard changes",
    "Message sent" : "Ujumbe umetumwa",
    "Redirect" : "Elekeza upya",
    "Continue to %s" : "Endelea katika %s",
    "Actions" : "Matendo",
    "New action" : "Kitendo kipya"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sw.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Muhimu",
    "Work" : "Kazi",
    "Personal" : "Binafsi",
    "To Do" : "Kufanya",
    "Later" : "Baadaye",
    "Mail" : "Msururu wa maduka",
    "Sign in with Google" : "Ingia kwa Google",
    "Save" : "Hifadhi",
    "Connect" : "Unganisha",
    "Auto" : "Auto",
    "Name" : "Jina",
    "Password" : "Nenosiri",
    "Manual" : "Manual",
    "None" : "Hakuna",
    "Signature" : "Saini",
    "Filters" : "Filters",
    "Go back" : "Rudi nyuma",
    "Change name" : "Change name",
    "Email address" : "Anwani ya barua pepe",
    "Cancel" : "Cancel",
    "General" : "Kuu",
    "Appearance" : "Mwonekano",
    "Layout" : "Mpangilio",
    "List" : "Orodha",
    "Sorting" : "Sorting",
    "Newest first" : "Mpya kwanza",
    "Oldest first" : "Ya zamani kwanza",
    "Shared with me" : "Shared with me",
    "Privacy" : "Faragha",
    "Security" : "Ulinzi",
    "About" : "Kuhusu",
    "Archive" : "Weka kumbukumbu",
    "Delete" : "Futa",
    "Search" : "Tafuta",
    "Send" : "Tuma",
    "Refresh" : "Refresh",
    "Ok" : "Sawa",
    "From" : "Tangu/ kutoka",
    "Select account" : "Chagua akaunti",
    "To" : "Mpaka/ hadi",
    "Cc" : "Cc",
    "Subject" : "Subject",
    "Smart picker" : "Smart picker",
    "Choose" : "Chagua",
    "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
    "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Confirm" : "Thibitisha",
    "No messages" : "Hakuna jumbe",
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Set reminder for next week" : "Set reminder for next week",
    "Favorite" : "Kipendwa",
    "Unread" : "Unread",
    "Read" : "Soma",
    "Delete message" : "Delete message",
    "More actions" : "Vitendo zaidi",
    "Back" : "Rudi",
    "Create task" : "Tengeneza jukumu",
    "Load more" : "Pakia zaidi",
    "Mark as unread" : "Weka alama kama haijasomwa",
    "Mark as read" : "Weka alama kama iliyosomwa",
    "Create event" : "Tengeneza matukio",
    "All day" : "Siku yote",
    "Attendees" : "Wahudhuriaji",
    "Description" : "Maelezo",
    "Create" : "Tengeneza",
    "Select" : "Chagua",
    "Comment" : "Maoni",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "More options" : "Mibadala zaidi",
    "Remove" : "Ondoa",
    "Last hour" : "Last hour",
    "Today" : "Leo",
    "Yesterday" : "Jana",
    "Last week" : "Wiki iliyopita",
    "Last month" : "Mwezi uliopita",
    "Choose target folder" : "Chagua kasha lililolengwa",
    "Favorites" : "Vipendwa",
    "Other" : "Mengine",
    "Forward" : "Mbele",
    "Translate" : "Tafsiri",
    "Move" : "Hamisha",
    "Remove account" : "Ondoa akaunti",
    "Remove {email}" : "Remove {email}",
    "Add folder" : "Ongeza kisanduku",
    "Folder name" : "Jina la kisanduku",
    "Saving" : "Saving",
    "Move up" : "Move up",
    "Move down" : "Move down",
    "Loading …" : "Inapakia  …",
    "Delete folder" : "Futa kisanduku",
    "Mark all as read" : "Mark all as read",
    "Rename" : "Ipe jina jipya",
    "Move folder" : "Move folder",
    "Clear cache" : "Clear cache",
    "Subscribed" : "Iliyojisajili",
    "Delete all messages" : "Futa jumbe zote ",
    "New message" : "Ujumbe mpya",
    "Edit message" : "Hariri ujumbe",
    "Draft" : "Draft",
    "Reply" : "Jibu",
    "Retry" : "Jaribu tene",
    "First day" : "First day",
    "Message" : "Message",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
    "Add" : "Ongeza",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Clear" : "Futa",
    "Close" : "Funga",
    "Body" : "Body",
    "Date" : "Tarehe",
    "Tags" : "Maoni",
    "Select tags" : "Chagua ukumbusho",
    "Custom" : "Mteja",
    "Add tag" : "Add tag",
    "Not found" : "Haipatikani",
    "Unsubscribe" : "Unsubscribe",
    "The message could not be translated" : "The message could not be translated",
    "Translation copied to clipboard" : "Translation copied to clipboard",
    "Translation could not be copied" : "Translation could not be copied",
    "Translate message" : "Translate message",
    "Source language to translate from" : "Source language to translate from",
    "Translate from" : "Translate from",
    "Target language to translate into" : "Target language to translate into",
    "Translate to" : "Translate to",
    "Translating" : "Translating",
    "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
    "Untitled event" : "Tukio lisilotajwa",
    "(organizer)" : "(Mratibu)",
    "Deleted" : "Vilivyofutwa",
    "Help" : "Msaada",
    "contains" : "contains",
    "matches" : "matches",
    "Actions" : "Matendo",
    "Priority" : "Kipaumbele",
    "Edit" : "Hariri",
    "Reset" : "Pangilia upya",
    "Client ID" : "Kitambulisho cha mteja",
    "Client secret" : "Siri ya mteja",
    "User" : "Mtumiaji",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Halali mpaka",
    "Certificate" : "Cheti",
    "Submit" : "Wasilisha",
    "Guest" : "Mgeni",
    "Group" : "Kundi",
    "Shared" : "Imeshirikishwa",
    "Shares" : "Shiriki",
    "Account connected" : "Akaunti imeunganishwa",
    "All" : "Zote",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "Nextcloud Mail" : "Nextcloud Mail",
    "Discard changes" : "Discard changes",
    "Message sent" : "Ujumbe umetumwa",
    "Redirect" : "Elekeza upya",
    "Continue to %s" : "Endelea katika %s",
    "Last 7 days" : "Siku 7 zilizopita"
},
"nplurals=2; plural=(n != 1);");
